==> hapi-fhir-structures-dstu3-2.2-sources.jar: org/hl7/fhir/dstu3/model/codesystems/AssertOperatorCodesEnumFactory.java <==
package org.hl7.fhir.dstu3.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Tue, Dec 6, 2016 09:42-0500 for FHIR v1.8.0


import org.hl7.fhir.dstu3.model.EnumFactory;

public class AssertOperatorCodesEnumFactory implements EnumFactory<AssertOperatorCodes> {

  public AssertOperatorCodes fromCode(String codeString) throws IllegalArgumentException {
    if (codeString == null || "".equals(codeString))
      return null;
    if ("equals".equals(codeString))
      return AssertOperatorCodes.EQUALS;
    if ("notEquals".equals(codeString))
      return AssertOperatorCodes.NOTEQUALS;
    if ("in".equals(codeString))
      return AssertOperatorCodes.IN;
    if ("notIn".equals(codeString))
      return AssertOperatorCodes.NOTIN;
    if ("greaterThan".equals(codeString))
      return AssertOperatorCodes.GREATERTHAN;
    if ("lessThan".equals(codeString))
      return AssertOperatorCodes.LESSTHAN;
    if ("empty".equals(codeString))
      return AssertOperatorCodes.EMPTY;
    if ("notEmpty".equals(codeString))
      return AssertOperatorCodes.NOTEMPTY;
    if ("contains".equals(codeString))
      return AssertOperatorCodes.CONTAINS;
    if ("notContains".equals(codeString))
      return AssertOperatorCodes.NOTCONTAINS;
    if ("eval".equals(codeString))
      return AssertOperatorCodes.EVAL;
    throw new IllegalArgumentException("Unknown AssertOperatorCodes code '"+codeString+"'");
  }

  public String toCode(AssertOperatorCodes code) {
    if (code == AssertOperatorCodes.EQUALS)
      return "equals";
    if (code == AssertOperatorCodes.NOTEQUALS)
      return "notEquals";
    if (code == AssertOperatorCodes.IN)
      return "in";
    if (code == AssertOperatorCodes.NOTIN)
      return "notIn";
    if (code == AssertOperatorCodes.GREATERTHAN)
      return "greaterThan";
    if (code == AssertOperatorCodes.LESSTHAN)
      return "lessThan";
    if (code == AssertOperatorCodes.EMPTY)
      return "empty";
    if (code == AssertOperatorCodes.NOTEMPTY)
      return "notEmpty";
    if (code == AssertOperatorCodes.CONTAINS)
      return "contains";
    if (code == AssertOperatorCodes.NOTCONTAINS)
      return "notContains";
    if (code == AssertOperatorCodes.EVAL)
      return "eval";
    return "?";
  }

    public String toSystem(AssertOperatorCodes code) {
      return code.getSystem();
      }

}

==> hapi-fhir-structures-dstu3-2.5-sources.jar: org/hl7/fhir/dstu3/model/codesystems/AssertOperatorCodesEnumFactory.java <==
package org.hl7.fhir.dstu3.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Mon, Apr 17, 2017 17:38-0400 for FHIR v3.0.1


import org.hl7.fhir.dstu3.model.EnumFactory;

public class AssertOperatorCodesEnumFactory implements EnumFactory<AssertOperatorCodes> {

  public AssertOperatorCodes fromCode(String codeString) throws IllegalArgumentException {
    if (codeString == null || "".equals(codeString))
      return null;
    if ("equals".equals(codeString))
      return AssertOperatorCodes.EQUALS;
    if ("notEquals".equals(codeString))
      return AssertOperatorCodes.NOTEQUALS;
    if ("in".equals(codeString))
      return AssertOperatorCodes.IN;
    if ("notIn".equals(codeString))
      return AssertOperatorCodes.NOTIN;
    if ("greaterThan".equals(codeString))
      return AssertOperatorCodes.GREATERTHAN;
    if ("lessThan".equals(codeString))
      return AssertOperatorCodes.LESSTHAN;
    if ("empty".equals(codeString))
      return AssertOperatorCodes.EMPTY;
    if ("notEmpty".equals(codeString))
      return AssertOperatorCodes.NOTEMPTY;
    if ("contains".equals(codeString))
      return AssertOperatorCodes.CONTAINS;
    if ("notContains".equals(codeString))
      return AssertOperatorCodes.NOTCONTAINS;
    if ("eval".equals(codeString))
      return AssertOperatorCodes.EVAL;
    throw new IllegalArgumentException("Unknown AssertOperatorCodes code '"+codeString+"'");
  }

  public String toCode(AssertOperatorCodes code) {
    if (code == AssertOperatorCodes.EQUALS)
      return "equals";
    if (code == AssertOperatorCodes.NOTEQUALS)
      return "notEquals";
    if (code == AssertOperatorCodes.IN)
      return "in";
    if (code == AssertOperatorCodes.NOTIN)
      return "notIn";
    if (code == AssertOperatorCodes.GREATERTHAN)
      return "greaterThan";
    if (code == AssertOperatorCodes.LESSTHAN)
      return "lessThan";
    if (code == AssertOperatorCodes.EMPTY)
      return "empty";
    if (code == AssertOperatorCodes.NOTEMPTY)
      return "notEmpty";
    if (code == AssertOperatorCodes.CONTAINS)
      return "contains";
    if (code == AssertOperatorCodes.NOTCONTAINS)
      return "notContains";
    if (code == AssertOperatorCodes.EVAL)
      return "eval";
    return "?";
  }

    public String toSystem(AssertOperatorCodes code) {
      return code.getSystem();
      }

}
